@@ -96,14 +96,14 @@ class AllChannels:
     __slots__ = ('guild',)
 
     def __init__(self, guild: Guild):
-        self.guild = guild
+        self.guild: Guild = guild
 
     @property
     def id(self) -> int:
         """:class:`int`: The ID sentinel used to represent all channels. Equivalent to the guild's ID minus 1."""
         return self.guild.id - 1
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'<AllChannels guild={self.guild}>'
 
 
@@ -145,6 +145,8 @@ class AppCommand(Hashable):
         The application command's name.
     description: :class:`str`
         The application command's description.
+    options: List[Union[:class:`AppCommand`, :class:`AppCommandGroup`]]
+        A list of options.
     default_member_permissions: Optional[:class:`~discord.Permissions`]
         The default member permissions that can run this command.
     dm_permission: :class:`bool`
@@ -743,6 +745,14 @@ class Argument:
         A list of choices for the command to choose from for this argument.
     parent: Union[:class:`AppCommand`, :class:`AppCommandGroup`]
         The parent application command that has this argument.
+    channel_types: List[:class:`~discord.ChannelType`]
+        The channel types that are allowed for this parameter.
+    min_value: Optional[Union[:class:`int`, :class:`float`]]
+        The minimum supported value for this parameter.
+    max_value: Optional[Union[:class:`int`, :class:`float`]]
+        The maximum supported value for this parameter.
+    autocomplete: :class:`bool`
+        Whether the argument has autocomplete.
     """
 
     __slots__ = (
@@ -751,6 +761,10 @@ class Argument:
         'description',
         'required',
         'choices',
+        'channel_types',
+        'min_value',
+        'max_value',
+        'autocomplete',
         'parent',
         '_state',
     )
@@ -770,6 +784,10 @@ class Argument:
         self.name: str = data['name']
         self.description: str = data['description']
         self.required: bool = data.get('required', False)
+        self.min_value: Optional[Union[int, float]] = data.get('min_value')
+        self.max_value: Optional[Union[int, float]] = data.get('max_value')
+        self.autocomplete: bool = data.get('autocomplete', False)
+        self.channel_types: List[ChannelType] = [try_enum(ChannelType, d) for d in data.get('channel_types', [])]
         self.choices: List[Choice[Union[int, float, str]]] = [
             Choice(name=d['name'], value=d['value']) for d in data.get('choices', [])
         ]
@@ -781,6 +799,10 @@ class Argument:
             'description': self.description,
             'required': self.required,
             'choices': [choice.to_dict() for choice in self.choices],
+            'channel_types': [channel_type.value for channel_type in self.channel_types],
+            'min_value': self.min_value,
+            'max_value': self.max_value,
+            'autocomplete': self.autocomplete,
             'options': [],
         }  # type: ignore # Type checker does not understand this literal.
 
@@ -798,12 +820,8 @@ class AppCommandGroup:
         The name of the subcommand.
     description: :class:`str`
         The description of the subcommand.
-    required: :class:`bool`
-        Whether the subcommand is required.
-    choices: List[:class:`Choice`]
-        A list of choices for the command to choose from for this subcommand.
-    arguments: List[:class:`Argument`]
-        A list of arguments.
+    options: List[Union[:class:`AppCommand`, :class:`AppCommandGroup`]]
+        A list of options.
     parent: Union[:class:`AppCommand`, :class:`AppCommandGroup`]
         The parent application command.
     """
@@ -812,9 +830,7 @@ class AppCommandGroup:
         'type',
         'name',
         'description',
-        'required',
-        'choices',
-        'arguments',
+        'options',
         'parent',
         '_state',
     )
@@ -827,20 +843,14 @@ class AppCommandGroup:
         self._from_data(data)
 
     def __repr__(self) -> str:
-        return f'<{self.__class__.__name__} name={self.name!r} type={self.type!r} required={self.required}>'
+        return f'<{self.__class__.__name__} name={self.name!r} type={self.type!r}>'
 
     def _from_data(self, data: ApplicationCommandOption) -> None:
         self.type: AppCommandOptionType = try_enum(AppCommandOptionType, data['type'])
         self.name: str = data['name']
         self.description: str = data['description']
-        self.required: bool = data.get('required', False)
-        self.choices: List[Choice[Union[int, float, str]]] = [
-            Choice(name=d['name'], value=d['value']) for d in data.get('choices', [])
-        ]
-        self.arguments: List[Argument] = [
-            Argument(parent=self, state=self._state, data=d)
-            for d in data.get('options', [])
-            if is_app_command_argument_type(d['type'])
+        self.options: List[Union[Argument, AppCommandGroup]] = [
+            app_command_option_factory(data=d, parent=self, state=self._state) for d in data.get('options', [])
         ]
 
     def to_dict(self) -> 'ApplicationCommandOption':
@@ -848,9 +858,7 @@ class AppCommandGroup:
             'name': self.name,
             'type': self.type.value,
             'description': self.description,
-            'required': self.required,
-            'choices': [choice.to_dict() for choice in self.choices],
-            'options': [arg.to_dict() for arg in self.arguments],
+            'options': [arg.to_dict() for arg in self.options],
         }  # type: ignore # Type checker does not understand this literal.
 
 
